@@ -90,9 +90,16 @@ function ajax_fk_close_click() {
 }
 
 function ajax_fk_search_keypress(e) {
-    if (e.which == 13) {
+    // Make search if hits ENTER
+    if (e.which === 13) {
         $(this).parent().find('.ajax-fk-search').click();
         return false;
+
+    // Closes the window and focus the origin widget
+    } else if (e.keyCode === 27) {
+        $(this).parent().parent().parent().find('.ajax-fk-show-window').click();
+        $(this).parent().parent().parent().find('input.ajax-fk').focus();
+        return false;
     }
 }
 
@@ -169,6 +176,9 @@ function ajax_fk_load(input, url) {
         if (fk_widgets[$(this).parent().find('input:first').attr('name')]['post_show_window']) {
             fk_widgets[$(this).parent().find('input:first').attr('name')]['post_show_window']();
         }
+
+        // Set focus on search input
+        $(this).parent().find('.ajax-fk-window').find('input#ajax-fk-search').focus();
     });
 }
 
